.. _cli:

Command Line Interface
======================

Rio is cross-platform event driven system built with love.

Subcommands
-----------

* :ref:`celery`
* :ref:`db`
* :ref:`init`
* :ref:`shell`
* :ref:`start`
* :ref:`runserver`
